==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/SquarePollHorizontal.md <==
# SquarePollHorizontal


```text
fontawesome-6/Solid/SquarePollHorizontal
```

```text
include('fontawesome-6/Solid/SquarePollHorizontal')
```



| Illustration | SquarePollHorizontal |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/SquarePollHorizontal.png) | ![illustration for SquarePollHorizontal](../../fontawesome-6/Solid/SquarePollHorizontal.Local.png) |




## SquarePollHorizontal

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element SquarePollHorizontal
include('fontawesome-6/Solid/SquarePollHorizontal')

' renders the element
SquarePollHorizontal('SquarePollHorizontal', 'Square Poll Horizontal', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element SquarePollHorizontal
include('fontawesome-6/Solid/SquarePollHorizontal')

' renders the element
SquarePollHorizontal('SquarePollHorizontal', 'Square Poll Horizontal', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/fontawesome-6/Solid/SquarePollHorizontal.md <==
# SquarePollHorizontal


```text
fontawesome-6/Solid/SquarePollHorizontal
```

```text
include('fontawesome-6/Solid/SquarePollHorizontal')
```



| Illustration | SquarePollHorizontal |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/SquarePollHorizontal.png) | ![illustration for SquarePollHorizontal](../../fontawesome-6/Solid/SquarePollHorizontal.Local.png) |




## SquarePollHorizontal

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element SquarePollHorizontal
include('fontawesome-6/Solid/SquarePollHorizontal')

' renders the element
SquarePollHorizontal('SquarePollHorizontal', 'Square Poll Horizontal', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element SquarePollHorizontal
include('fontawesome-6/Solid/SquarePollHorizontal')

' renders the element
SquarePollHorizontal('SquarePollHorizontal', 'Square Poll Horizontal', 'an optional tech label', 'an optional description')
@enduml
```
